@@ -35,7 +35,8 @@ MBD_SSHPUBKEYFILE="${MBD_HOME}/.ssh/id_dsa.pub"
 MBD_GNUPGSECRING="${MBD_HOME}/.gnupg/secring.gpg"
 MBD_GNUPG_KEYNAME="Mini-Buildd Automatic Signing Key"
 
-MBD_MDINSTALLCONFIGFILE="${MBD_HOME}/.mini-dinstall.conf"
+MBD_REPREPRO_DISTSFILE="${MBD_HOME}/rep/conf/distributions"
+MBD_REPREPRO_INCOMINGFILE="${MBD_HOME}/rep/conf/incoming"
 
 MBD_HTML_INDEXFILE="${MBD_HOME}/public_html/index.html"
 
@@ -46,7 +47,7 @@ MBD_SCHROOTCONFIGFILE="/etc/schroot/chroot.d/mini-buildd"
 # Maintainer name of autobuilder (goes to .sbuildrc, and used to reject direct binary uploads).
 MBD_AUTOBUILD_MAINTAINER="Mini-Buildd Builder"
 
-MBD_INCOMING="${MBD_HOME}/rep/mini-dinstall/incoming"
+MBD_INCOMING="${MBD_HOME}/rep/incoming"
 MBD_INCOMING_BPO="${MBD_INCOMING}/backports"
 
 MBD_LOG="logger -t mini-buildd@$(hostname)[$(basename -- "${0}")] -p user.info"
@@ -349,8 +350,7 @@ mbdLvmVgName()
 mbdGetSrcVar() # dist kind arch
 {
 	local srcAny="mbd_src_${1}_${2}_any"
-	local srcArch="mbd_src_${1}_${2}_${arch}"
-	local src="${srcAny}"
+	local srcArch="mbd_src_${1}_${2}_${3}"
 	if [ -n "${!srcArch}" ]; then
 		echo -n "${srcArch}"
 	else
@@ -375,8 +375,10 @@ mbdGenConf()
 	local noheader="${5}"
 
 	# Generate local source list variable for ourselves (mbd)
-	eval "local mbd_src_${dist}_mbd_any=\"http://${mbd_rephost}/~mini-buildd/rep ${dist}-${mbd_id}/\""
-	eval "local mbd_src_${dist}_mbd_experimental_any=\"http://${mbd_rephost}/~mini-buildd/rep ${dist}-${mbd_id}-experimental/\""
+	local d
+	for d in experimental unstable testing stable; do
+		eval "local mbd_src_${dist}_mbd_${d}_any=\"http://${mbd_rephost}/~mini-buildd/rep ${dist}-${mbd_id}-${d} main contrib non-free\""
+	done
 
 	for kind in ${kinds}; do
 		local src=$(mbdGetSrcVar ${dist} ${kind} ${arch})
